@@ -277,7 +277,7 @@ def tagger(sentence: str, task = 'full', lang = 'MSA') -> list:
     # Check if the ALMA dictionary has been loaded
     # if settings.flag == True:
     #     settings.flag = False
-    settings.div_dic = load_ALMA_dic(r'~\demo_sna\dic_data\ALMA_dic_first_500records_with_language_and_task.pickle')
+    settings.div_dic = load_ALMA_dic(r'data\my_data.pickle')
    
     
     # Perform lemmatization on the input sentence
